CedarBackup3.extend.sysinfo — cedar-backup3 3.10.0 documentation

# CedarBackup3.extend.sysinfo

Provides an extension to save off important system recovery information.

This is a simple Cedar Backup extension used to save off important system recovery information. It saves off three types of information:

> - Currently-installed Debian packages via `dpkg --get-selections`

> - Disk partition information via `fdisk -l`

> - System-wide mounted filesystem contents, via `ls -laR`

The saved-off information is placed into the collect directory and is compressed using `bzip2` to save space.

This extension relies on the options and collect configurations in the standard Cedar Backup configuration file, but requires no new configuration of its own. No public functions other than the action are exposed since all of this is pretty simple.

Note: If the `dpkg` or `fdisk` commands cannot be found in their normal locations or executed by the current user, those steps will be skipped and a note will be logged at the INFO level.

author:

  Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.extend.sysinfo.logger

CedarBackup3.extend.sysinfo.DPKG_PATH = '/usr/bin/dpkg'

CedarBackup3.extend.sysinfo.FDISK_PATH = '/sbin/fdisk'

CedarBackup3.extend.sysinfo.DPKG_COMMAND

CedarBackup3.extend.sysinfo.FDISK_COMMAND

CedarBackup3.extend.sysinfo.LS_COMMAND = ['ls', '-laR', '/']

CedarBackup3.extend.sysinfo.executeAction(configPath, options, config)

  Executes the sysinfo backup action.

  Parameters:

    - configPath (String representing a path on disk) – Path to configuration file on disk

    - options (Options object) – Program command-line options

    - config (Config object) – Program configuration

  Raises:

    - ValueError – Under many generic error conditions

    - IOError – If the backup process fails for some reason